<?php
/*
Plugin Name: wp_recent_comments_with_newmark
Plugin URI: http://www.koikikukan.com/plugins/
Description: 最近のコメント一覧に新着マークを表示します。
Version: 0.0.2
Author: Yujiro Araki
Author URI: http://www.koikikukan.com/
*/

class WP_Widget_Recent_Comments_With_NewMark extends WP_Widget {

    function WP_Widget_Recent_Comments_With_NewMark() {
        $widget_ops = array('classname' => 'widget_recent_comments_with_newmark', 'description' => __( "The most recent comments on your site with new mark", 'wp_recent_comments_with_newmark') );
        $this->WP_Widget('recent-comments-with-newmark', __('Recent Comments with New Mark', 'wp_recent_comments_with_newmark'), $widget_ops);
        $this->alt_option_name = 'widget_recent_comments_with_newmark';

        add_action( 'save_comment', array(&$this, 'flush_widget_cache') );
        add_action( 'deleted_comment', array(&$this, 'flush_widget_cache') );
        add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
    }

	function widget( $args, $instance ) {
		global $comments, $comment;

		$cache = wp_cache_get('widget_recent_comments', 'widget');

		if ( ! is_array( $cache ) )
			$cache = array();

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

        if ( !$number = (int) $instance['number'] )
            $number = 10;
        else if ( $number < 1 )
            $number = 1;
//        else if ( $number > 15 )
//            $number = 15;

        if ( !$hour = (int) $instance['hour'] )
            $hour = 24;

        if ( !$html = $instance['html'] ) {
              $html = '<span style="color:#e50003">New!!</span>';
        }

        if ( !$time = $instance['time'] ) {
              $time = 'n/j';
        }

 		extract($args, EXTR_SKIP);
 		$output = '';
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Recent Comments' ) : $instance['title'], $instance, $this->id_base );

		if ( empty( $instance['number'] ) || ! $number = absint( $instance['number'] ) )
 			$number = 5;

		$comments = get_comments( apply_filters( 'widget_comments_args', array( 'number' => $number, 'status' => 'approve', 'post_status' => 'publish' ) ) );
		$output .= $before_widget;
		if ( $title )
			$output .= $before_title . $title . $after_title;

		$output .= '<ul id="recentcomments">';
		if ( $comments ) {
			// Prime cache for associated posts. (Prime post term cache if we need it for permalinks.)
			$post_ids = array_unique( wp_list_pluck( $comments, 'comment_post_ID' ) );
			_prime_post_caches( $post_ids, strpos( get_option( 'permalink_structure' ), '%category%' ), false );

			foreach ( (array) $comments as $comment) {
				$output .=  '<li class="recentcomments">' . /* translators: comments widget: 1: comment author, 2: post link */ sprintf(_x('%1$s on %2$s', 'widgets'), get_comment_author_link(), '<a href="' . esc_url( get_comment_link($comment->comment_ID) ) . '">' . get_the_title($comment->comment_post_ID) . '</a>');
$output .= " " .get_comment_date($time);
		        $current_date = date('U');
		        $comment_date = get_comment_date('U');
		        $min = ceil(date('U',($current_date - $comment_date))/3600);
		        if ($min+8 < $hour) {
		            $output .= " " . $html;
		        }
				$output .= '</li>';
			}
 		}
		$output .= '</ul>';
		$output .= $after_widget;

		echo $output;
		$cache[$args['widget_id']] = $output;
		wp_cache_set('widget_recent_comments', $cache, 'widget');
	}

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['hour'] = $new_instance['hour'];
        $instance['time'] = $new_instance['time'];
        $instance['html'] = $new_instance['html'];
        $this->flush_widget_cache();

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_recent_comments']) )
            delete_option('widget_recent_comments');

        return $instance;
    }

    function flush_widget_cache() {
        wp_cache_delete('widget_recent_comments', 'widget');
    }

    function form( $instance ) {
        $title = isset($instance['title']) ? esc_attr($instance['title']) : '';
        if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
            $number = 5;
        if ( !isset($instance['hour']) || !$hour = (int) $instance['hour'] )
            $hour = 24;
        if ( !isset($instance['time']) || !$time = $instance['time'] )
            $time = 'n/j';
        if ( !isset($instance['html']) || !$html = $instance['html'] )
//            $html = '&lt;span style=&quot;color:#e50003&quot;&gt;New!!&lt;/span&gt;';
            $html = '<span style="color:#e50003">New!!</span>';
?>
        <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

        <p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of comments to show:'); ?></label>
        <input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>

        <p><label for="<?php echo $this->get_field_id('time'); ?>"><?php _e('Format of time:', 'wp_recent_comments_with_newmark'); ?></label>
        <input id="<?php echo $this->get_field_id('time'); ?>" name="<?php echo $this->get_field_name('time'); ?>" type="text" value="<?php echo $time; ?>" size="10" /></p>

        <p><label for="<?php echo $this->get_field_id('hour'); ?>"><?php _e('Time:', 'wp_recent_comments_with_newmark'); ?></label>
        <input id="<?php echo $this->get_field_id('hour'); ?>" name="<?php echo $this->get_field_name('hour'); ?>" type="text" value="<?php echo $hour; ?>" size="3" /></p>

<?php
$html = preg_replace('/&/', '&amp;', $html);
$html = preg_replace('/</', '&lt;', $html);
$html = preg_replace('/>/', '&gt;', $html);
$html = preg_replace('/"/', '&quot;', $html);
?>
        <p><label for="<?php echo $this->get_field_id('html'); ?>"><?php _e('HTML for New Mark:', 'wp_recent_comments_with_newmark'); ?></label>
        <textarea class="widefat" id="<?php echo $this->get_field_id('html'); ?>" name="<?php echo $this->get_field_name('html'); ?>"><?php echo $html; ?></textarea></p>

<?php /*        <p><label for="<?php echo $this->get_field_id('image'); ?>"><?php _e('Image(option):'); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('image'); ?>" name="<?php echo $this->get_field_name('image'); ?>" type="text" value="<?php echo $image; ?>" size="10" /></p>
*/ ?>
<?php
    }
}

function WP_Widget_Recent_Comments_With_NewMarkInit() {
    load_plugin_textdomain( 'wp_recent_comments_with_newmark', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
    register_widget('WP_Widget_Recent_Comments_With_NewMark');
}

add_action('widgets_init', 'WP_Widget_Recent_Comments_With_NewMarkInit');

